Gentelella Alela! |

Welcome,

## John Doe

Total Sessions

## 231,809

Total Revenue

## $ 231,809

Total Sessions

## 231,809

Total Sessions

## 231,809

### Network Activities Graph title sub-title

December 30, 2014 - January 28, 2015

## App Devices Sessions

#### App Versions

1.5.2
60% Complete
123k
1.5.3
60% Complete
53k
1.5.4
60% Complete
23k
1.5.5
60% Complete
3k
0.1.5.6
60% Complete
1k

## Daily users Sessions

Top 5 | Device Progress
--- | ---
IOS | 30%
Android | 10%
Blackberry | 20%
Symbian | 15%
Others | 30%

## Profile Settings Sessions

- Achievements
- Favorites
- Activities
- Settings
- Logout

## User Uptake

Escudor Wireless 1.0 This sis
SSD
89%
Mobile Access Smart Phone
App
79%
WAN access users Total 69%
Usr
69%

## Today's Weather Sessions

Monday, 07:30 AM F C

## Texas
Partly Cloudy Day

### 23

## Mon

### 25

##### 15 km/h

## Tue

### 25

##### 12 km/h

## Wed

### 27

##### 14 km/h

## Thu

### 28

##### 15 km/h

## Fri

### 28

##### 11 km/h

## Sat

### 26

##### 10 km/h

## Incomes Sessions

- Subscription
- Auto Renewal
- Help Desk
- Donations